@@ -1,5 +1,6 @@
 import hashlib
 import os
+import platform
 from assertpy import assert_that
 from typing import Dict, List, Union
 from pathlib import Path
@@ -36,7 +37,13 @@ class ArtifactEntry:
         assert_that(local_root_path).is_not_none()
         assert_that(artifact_id).is_not_none()
 
-        local_path = os.path.join(local_root_path, self.path)
+        if platform.system() == "Windows":
+            # OS가 윈도우인 경우 path seperator 를 "/"로 통일시켜줌.
+            local_path = os.path.join(local_root_path, self.path.replace("/", os.path.sep))
+        else:
+            local_path = os.path.join(local_root_path, self.path)
+
+
         i_last_separator = len(local_path) - local_path[::-1].find(os.path.sep) - 1
         Path(local_path[:i_last_separator]).mkdir(parents=True, exist_ok=True)
 
@@ -46,14 +53,14 @@ class ArtifactEntry:
         self.local_path = local_path
 
     # ArtifactEntry 객체를 기반으로 파일 업로드 수행
-    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry]) -> bool:
+    def upload(self, upload_type: str, root_path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_list: List[grpc_ArtifactEntry]) -> bool:
         assert_that(root_path).is_not_none()
         assert_that(run_id).is_not_none()
         assert_that(artifact_id).is_not_none()
         assert_that(last_file_yn).is_not_none()
         assert_that(artifact_digest).is_not_none()
         assert_that(entry_list).is_not_none()
-        return interface.upload_file(upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_digest, self.digest, entry_list)
+        return interface.upload_file( upload_type, self.local_path, root_path, self.path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, self.digest, entry_list)
 
     def __str__(self) -> str:
         return f"{{path:{self.path},local_path:{self.local_path}}}"
@@ -120,7 +127,7 @@ class Artifacts:
     # Artifact의 정보를 전송하고, ArtifactEntry 각각의 파일을 전송한다
     def upload(self) -> bool:
         # Interface.py의 upoad_artifact ( grpc_interface.py의 upoad_artifact)를 호출 하여 artifact 정보에 대해 전송
-        entry_dict = {entry.path: entry for entry in self.entry_list}
+        entry_dict = {entry.path.replace("\\", "/"): entry for entry in self.entry_list}
         entry_list: List(grpc_ArtifactEntry) = []
         hasher = hashlib.md5()
         #TODO: 상태에 따라서 status 변경
@@ -147,7 +154,7 @@ class Artifacts:
                 upload_type = "ARTI_REPO"
             else:
                 upload_type = "ARTI_FILES"
-            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn,  self.run.team_name, self.run.exp_name, artifact_digest, entry_list)
+            succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn,  self.run.team_name, self.run.exp_name, self.name, self.type, artifact_digest, entry_list)
             if not succeeded:
                 return False
         return True
