@@ -30,6 +30,15 @@ def get_grpc_host() -> str:
     global grpc_host
     return grpc_host
 
+http_host="54.180.86.146:9011"
+
+def set_http_host(http_host_: str) -> None:
+    global http_host
+    http_host = http_host_
+
+def get_http_host() -> str:
+    global http_host
+    return http_host
 def upload_config():
     pass
 
@@ -61,7 +70,7 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
 
 CHUNK_SIZE = 1024 * 1024  # 1MB
 
-def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> UploadFileRequest:
+def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str, teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> UploadFileRequest:
     yield UploadFileRequest(
         uploadType = upload_type,
         file=FileRecord(file=FileItem(
@@ -72,6 +81,8 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
         )),
         artifact_id=artifact_id,
         run_id=run_id,
+        artifactName=artifact_name,
+        artifactType=artifact_type,
         digest=entry_digest,
         last_file_yn=last_file_yn,
         authorization=http_interface.get_jwt_key(),
@@ -93,18 +104,22 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
                 )),
                 artifact_id=artifact_id,
                 run_id=run_id,
+                artifactName=artifact_name,
+                artifactType=artifact_type,
                 digest=entry_digest,
                 last_file_yn=last_file_yn,
                 authorization=http_interface.get_jwt_key(),
+                teamName=teamName,
+                expName=expName,
                 total_file_info=TotalFileInfo(
                     digest=artifact_digest,
                     entry=entry_list,
                 ),
             )
 
-def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str,teamName: str, expName: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> bool:
+def upload_file( upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int, last_file_yn: str,teamName: str, expName: str, artifact_name: str, artifact_type: str, artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry]) -> bool:
 
-    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_digest, entry_digest, entry_list))
+    rsp: UploadFileResponse = get_stub().upload_file(load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName, artifact_name, artifact_type, artifact_digest, entry_digest, entry_list))
     return rsp.rsp_result.result == "success"
 
 def save_file(file_path: str, rsps) -> None:
@@ -162,7 +177,7 @@ def download_artifact():
     pass
 
 def login(key: str) -> bool:
-    rsp = http_interface.login(key)
+    rsp = http_interface.login(get_http_host(),key)
     if rsp["result"] == "success":
 
         grpc_url = get_grpc_host()
@@ -176,7 +191,7 @@ def login(key: str) -> bool:
     return rsp["result"] == "success"
 
 def init(exp_name: str="", team_name: str="", run_name: str="", config: Dict=None) -> Dict:
-    return http_interface.init(exp_name, team_name, run_name, config)
+    return http_interface.init(get_http_host(),exp_name, team_name, run_name, config)
 
 def finish(data: Dict) -> Dict:
-    return http_interface.finish(data)
+    return http_interface.finish(get_http_host(),data)
